@@ -1,7 +1,7 @@
 def make_sneath_dict() -> dict[tuple[str, str], int]:
     """
-    :return: A dictionary representative of TABLE 2 from Relations between Chemical Structure and Biological Activity
-             in Peptides by P. H. A. SNEATH. Keys are pairs of strings. Cf. scientific paper for more details on how
+    :return: A dictionary representative of TABLE 2 from 'Relations between Chemical Structure and Biological Activity
+             in Peptides' by P. H. A. Sneath. Keys are pairs of strings. Cf. scientific paper for more details on how
              those scores are derived.
     """
     sneath_dict: dict[tuple[str, str], int] = {
@@ -411,6 +411,11 @@ def make_sneath_dict() -> dict[tuple[str, str], int]:
 
 
 def make_miyata_dict() -> dict[tuple[str, str], float]:
+    """
+    :return: A dictionary representative of TABLE 1 from 'Two Types of Amino Acid Substitutions in Protein Evolution'
+             by Takashi Miyata, Sanzo Miyazawa, and Teruo Yasunaga. Keys are pairs of strings. Cf. scientific paper for
+             more details on how those scores are derived.
+    """
     miyata_dict: dict[tuple[str, str], float] = {
         ('C', 'C'): 0,
         ('P', 'C'): 1.33,
@@ -817,408 +822,827 @@ def make_miyata_dict() -> dict[tuple[str, str], float]:
     return miyata_dict
 
 
-def make_epstein_dict() -> dict[tuple[str, str], float]:
+def make_symmetric_epstein_dict() -> dict[tuple[str, str], float]:
+    """
+    :return: A symmetrised* version of the dictionary representative of TABLE 2 from 'Non-randomness of Amino-acid
+             Changes in the Evolution of Homologous Proteins' by Charles J. Epstein. Keys are pairs of strings. Cf.
+             scientific paper for more details on how those scores are derived.
+             * cf. paper for formula used to infer the symmetrised version (mean).
+    """
     epstein_dict: dict[tuple[str, str], float] = {
-        ('F', 'F'): 0.0,
-        ('M', 'F'): 0.07500000000000001,
-        ('L', 'F'): 0.11499999999999999,
-        ('I', 'F'): 0.11499999999999999,
-        ('V', 'F'): 0.15000000000000002,
-        ('P', 'F'): 0.15000000000000002,
-        ('Y', 'F'): 0.20500000000000002,
-        ('W', 'F'): 0.22999999999999998,
-        ('C', 'F'): 0.25,
-        ('A', 'F'): 0.46499999999999997,
-        ('G', 'F'): 0.5700000000000001,
-        ('S', 'F'): 0.81,
-        ('T', 'F'): 0.81,
-        ('H', 'F'): 0.8,
-        ('E', 'F'): 1.0,
-        ('Q', 'F'): 1.0,
-        ('D', 'F'): 1.0,
-        ('N', 'F'): 1.0,
-        ('K', 'F'): 1.0,
-        ('R', 'F'): 1.0,
-        ('F', 'M'): 0.07500000000000001,
-        ('M', 'M'): 0.0,
-        ('L', 'M'): 0.04,
-        ('I', 'M'): 0.04,
-        ('V', 'M'): 0.1,
-        ('P', 'M'): 0.1,
-        ('Y', 'M'): 0.235,
-        ('W', 'M'): 0.28,
-        ('C', 'M'): 0.215,
-        ('A', 'M'): 0.43,
-        ('G', 'M'): 0.49,
-        ('S', 'M'): 0.8,
-        ('T', 'M'): 0.8,
-        ('H', 'M'): 0.8,
-        ('E', 'M'): 1.0,
-        ('Q', 'M'): 1.0,
-        ('D', 'M'): 1.0,
-        ('N', 'M'): 1.0,
-        ('K', 'M'): 1.0,
-        ('R', 'M'): 1.0,
-        ('F', 'L'): 0.11499999999999999,
-        ('M', 'L'): 0.04,
-        ('L', 'L'): 0.0,
-        ('I', 'L'): 0.0,
-        ('V', 'L'): 0.04,
-        ('P', 'L'): 0.04,
-        ('Y', 'L'): 0.25,
-        ('W', 'L'): 0.305,
-        ('C', 'L'): 0.20500000000000002,
-        ('A', 'L'): 0.43,
-        ('G', 'L'): 0.525,
-        ('S', 'L'): 0.8,
-        ('T', 'L'): 0.8,
-        ('H', 'L'): 0.905,
-        ('E', 'L'): 1.0,
-        ('Q', 'L'): 1.0,
-        ('D', 'L'): 1.0,
-        ('N', 'L'): 1.0,
-        ('K', 'L'): 1.0,
-        ('R', 'L'): 1.005,
-        ('F', 'I'): 0.11499999999999999,
-        ('M', 'I'): 0.04,
-        ('L', 'I'): 0.0,
-        ('I', 'I'): 0.0,
-        ('V', 'I'): 0.04,
-        ('P', 'I'): 0.04,
-        ('Y', 'I'): 0.25,
-        ('W', 'I'): 0.305,
-        ('C', 'I'): 0.20500000000000002,
-        ('A', 'I'): 0.43,
-        ('G', 'I'): 0.525,
-        ('S', 'I'): 0.8,
-        ('T', 'I'): 0.8,
-        ('H', 'I'): 0.905,
-        ('E', 'I'): 1.0,
-        ('Q', 'I'): 1.0,
-        ('D', 'I'): 1.0,
-        ('N', 'I'): 1.0,
-        ('K', 'I'): 1.0,
-        ('R', 'I'): 1.005,
-        ('F', 'V'): 0.15000000000000002,
-        ('M', 'V'): 0.1,
-        ('L', 'V'): 0.04,
-        ('I', 'V'): 0.04,
-        ('V', 'V'): 0.0,
-        ('P', 'V'): 0.0,
-        ('Y', 'V'): 0.28,
-        ('W', 'V'): 0.335,
-        ('C', 'V'): 0.2,
-        ('A', 'V'): 0.405,
-        ('G', 'V'): 0.51,
-        ('S', 'V'): 0.8,
-        ('T', 'V'): 0.8,
-        ('H', 'V'): 0.805,
-        ('E', 'V'): 1.0,
-        ('Q', 'V'): 1.0,
-        ('D', 'V'): 1.0,
-        ('N', 'V'): 1.0,
-        ('K', 'V'): 1.0,
-        ('R', 'V'): 1.0150000000000001,
-        ('F', 'P'): 0.15000000000000002,
-        ('M', 'P'): 0.1,
-        ('L', 'P'): 0.04,
-        ('I', 'P'): 0.04,
-        ('V', 'P'): 0.0,
-        ('P', 'P'): 0.0,
-        ('Y', 'P'): 0.28,
-        ('W', 'P'): 0.335,
-        ('C', 'P'): 0.2,
-        ('A', 'P'): 0.405,
-        ('G', 'P'): 0.51,
-        ('S', 'P'): 0.8,
-        ('T', 'P'): 0.8,
-        ('H', 'P'): 0.805,
-        ('E', 'P'): 1.0,
-        ('Q', 'P'): 1.0,
-        ('D', 'P'): 1.0,
-        ('N', 'P'): 1.0,
-        ('K', 'P'): 1.0,
-        ('R', 'P'): 1.0150000000000001,
-        ('F', 'Y'): 0.20500000000000002,
-        ('M', 'Y'): 0.235,
-        ('L', 'Y'): 0.25,
-        ('I', 'Y'): 0.25,
-        ('V', 'Y'): 0.28,
-        ('P', 'Y'): 0.28,
-        ('Y', 'Y'): 0.0,
-        ('W', 'Y'): 0.07500000000000001,
-        ('C', 'Y'): 0.19,
-        ('A', 'Y'): 0.335,
-        ('G', 'Y'): 0.43,
-        ('S', 'Y'): 0.62,
-        ('T', 'Y'): 0.61,
-        ('H', 'Y'): 0.6,
-        ('E', 'Y'): 0.8,
-        ('Q', 'Y'): 0.8,
-        ('D', 'Y'): 0.81,
-        ('N', 'Y'): 0.81,
-        ('K', 'Y'): 0.8,
-        ('R', 'Y'): 0.8,
-        ('F', 'W'): 0.22999999999999998,
-        ('M', 'W'): 0.28,
-        ('L', 'W'): 0.305,
-        ('I', 'W'): 0.305,
-        ('V', 'W'): 0.335,
-        ('P', 'W'): 0.335,
-        ('Y', 'W'): 0.07500000000000001,
-        ('W', 'W'): 0.0,
-        ('C', 'W'): 0.265,
-        ('A', 'W'): 0.395,
-        ('G', 'W'): 0.485,
-        ('S', 'W'): 0.63,
-        ('T', 'W'): 0.63,
-        ('H', 'W'): 0.61,
-        ('E', 'W'): 0.81,
-        ('Q', 'W'): 0.81,
-        ('D', 'W'): 0.81,
-        ('N', 'W'): 0.81,
-        ('K', 'W'): 0.81,
-        ('R', 'W'): 0.8,
-        ('F', 'C'): 0.25,
-        ('M', 'C'): 0.215,
-        ('L', 'C'): 0.20500000000000002,
-        ('I', 'C'): 0.20500000000000002,
-        ('V', 'C'): 0.2,
-        ('P', 'C'): 0.2,
-        ('Y', 'C'): 0.19,
-        ('W', 'C'): 0.265,
-        ('C', 'C'): 0.0,
-        ('A', 'C'): 0.235,
-        ('G', 'C'): 0.325,
-        ('S', 'C'): 0.6,
-        ('T', 'C'): 0.6,
-        ('H', 'C'): 0.615,
-        ('E', 'C'): 0.805,
-        ('Q', 'C'): 0.805,
-        ('D', 'C'): 0.8,
-        ('N', 'C'): 0.8,
-        ('K', 'C'): 0.805,
-        ('R', 'C'): 0.815,
-        ('F', 'A'): 0.46499999999999997,
-        ('M', 'A'): 0.43,
-        ('L', 'A'): 0.43,
-        ('I', 'A'): 0.43,
-        ('V', 'A'): 0.405,
-        ('P', 'A'): 0.405,
-        ('Y', 'A'): 0.335,
-        ('W', 'A'): 0.395,
-        ('C', 'A'): 0.235,
-        ('A', 'A'): 0.0,
-        ('G', 'A'): 0.1,
-        ('S', 'A'): 0.4,
-        ('T', 'A'): 0.405,
-        ('H', 'A'): 0.44499999999999995,
-        ('E', 'A'): 0.62,
-        ('Q', 'A'): 0.62,
-        ('D', 'A'): 0.615,
-        ('N', 'A'): 0.615,
-        ('K', 'A'): 0.62,
-        ('R', 'A'): 0.645,
-        ('F', 'G'): 0.5700000000000001,
-        ('M', 'G'): 0.49,
-        ('L', 'G'): 0.525,
-        ('I', 'G'): 0.525,
-        ('V', 'G'): 0.51,
-        ('P', 'G'): 0.51,
-        ('Y', 'G'): 0.43,
-        ('W', 'G'): 0.485,
-        ('C', 'G'): 0.325,
-        ('A', 'G'): 0.1,
-        ('G', 'G'): 0.0,
-        ('S', 'G'): 0.31,
-        ('T', 'G'): 0.325,
-        ('H', 'G'): 0.38,
-        ('E', 'G'): 0.54,
-        ('Q', 'G'): 0.54,
-        ('D', 'G'): 0.525,
-        ('N', 'G'): 0.525,
-        ('K', 'G'): 0.54,
-        ('R', 'G'): 0.5700000000000001,
-        ('F', 'S'): 0.81,
-        ('M', 'S'): 0.8,
-        ('L', 'S'): 0.8,
-        ('I', 'S'): 0.8,
-        ('V', 'S'): 0.8,
-        ('P', 'S'): 0.8,
-        ('Y', 'S'): 0.62,
-        ('W', 'S'): 0.63,
-        ('C', 'S'): 0.6,
-        ('A', 'S'): 0.4,
-        ('G', 'S'): 0.31,
-        ('S', 'S'): 0.0,
-        ('T', 'S'): 0.03,
-        ('H', 'S'): 0.1,
-        ('E', 'S'): 0.215,
-        ('Q', 'S'): 0.215,
-        ('D', 'S'): 0.20500000000000002,
-        ('N', 'S'): 0.20500000000000002,
-        ('K', 'S'): 0.215,
-        ('R', 'S'): 0.24,
-        ('F', 'T'): 0.81,
-        ('M', 'T'): 0.8,
-        ('L', 'T'): 0.8,
-        ('I', 'T'): 0.8,
-        ('V', 'T'): 0.8,
-        ('P', 'T'): 0.8,
-        ('Y', 'T'): 0.61,
-        ('W', 'T'): 0.63,
-        ('C', 'T'): 0.6,
-        ('A', 'T'): 0.405,
-        ('G', 'T'): 0.325,
-        ('S', 'T'): 0.03,
-        ('T', 'T'): 0.0,
-        ('H', 'T'): 0.08,
-        ('E', 'T'): 0.21,
-        ('Q', 'T'): 0.21,
-        ('D', 'T'): 0.2,
-        ('N', 'T'): 0.2,
-        ('K', 'T'): 0.21,
-        ('R', 'T'): 0.22,
-        ('F', 'H'): 0.8,
-        ('M', 'H'): 0.8,
-        ('L', 'H'): 0.905,
-        ('I', 'H'): 0.905,
-        ('V', 'H'): 0.805,
-        ('P', 'H'): 0.805,
-        ('Y', 'H'): 0.6,
-        ('W', 'H'): 0.61,
-        ('C', 'H'): 0.615,
-        ('A', 'H'): 0.44499999999999995,
-        ('G', 'H'): 0.38,
-        ('S', 'H'): 0.1,
-        ('T', 'H'): 0.08,
-        ('H', 'H'): 0.0,
-        ('E', 'H'): 0.2,
-        ('Q', 'H'): 0.2,
-        ('D', 'H'): 0.21,
-        ('N', 'H'): 0.21,
-        ('K', 'H'): 0.2,
-        ('R', 'H'): 0.2,
-        ('F', 'E'): 1.0,
-        ('M', 'E'): 1.0,
-        ('L', 'E'): 1.0,
-        ('I', 'E'): 1.0,
-        ('V', 'E'): 1.0,
-        ('P', 'E'): 1.0,
-        ('Y', 'E'): 0.8,
-        ('W', 'E'): 0.81,
-        ('C', 'E'): 0.805,
-        ('A', 'E'): 0.62,
-        ('G', 'E'): 0.54,
-        ('S', 'E'): 0.215,
-        ('T', 'E'): 0.21,
-        ('H', 'E'): 0.2,
-        ('E', 'E'): 0.0,
-        ('Q', 'E'): 0.0,
-        ('D', 'E'): 0.03,
-        ('N', 'E'): 0.03,
-        ('K', 'E'): 0.0,
-        ('R', 'E'): 0.05,
-        ('F', 'Q'): 1.0,
-        ('M', 'Q'): 1.0,
-        ('L', 'Q'): 1.0,
-        ('I', 'Q'): 1.0,
-        ('V', 'Q'): 1.0,
-        ('P', 'Q'): 1.0,
-        ('Y', 'Q'): 0.8,
-        ('W', 'Q'): 0.81,
-        ('C', 'Q'): 0.805,
-        ('A', 'Q'): 0.62,
-        ('G', 'Q'): 0.54,
-        ('S', 'Q'): 0.215,
-        ('T', 'Q'): 0.21,
-        ('H', 'Q'): 0.2,
-        ('E', 'Q'): 0.0,
-        ('Q', 'Q'): 0.0,
-        ('D', 'Q'): 0.03,
-        ('N', 'Q'): 0.03,
-        ('K', 'Q'): 0.0,
-        ('R', 'Q'): 0.05,
-        ('F', 'D'): 1.0,
-        ('M', 'D'): 1.0,
-        ('L', 'D'): 1.0,
-        ('I', 'D'): 1.0,
-        ('V', 'D'): 1.0,
-        ('P', 'D'): 1.0,
-        ('Y', 'D'): 0.81,
-        ('W', 'D'): 0.81,
-        ('C', 'D'): 0.8,
-        ('A', 'D'): 0.615,
-        ('G', 'D'): 0.525,
-        ('S', 'D'): 0.20500000000000002,
-        ('T', 'D'): 0.2,
-        ('H', 'D'): 0.21,
-        ('E', 'D'): 0.03,
-        ('Q', 'D'): 0.03,
-        ('D', 'D'): 0.0,
-        ('N', 'D'): 0.0,
-        ('K', 'D'): 0.03,
-        ('R', 'D'): 0.08,
-        ('F', 'N'): 1.0,
-        ('M', 'N'): 1.0,
-        ('L', 'N'): 1.0,
-        ('I', 'N'): 1.0,
-        ('V', 'N'): 1.0,
-        ('P', 'N'): 1.0,
-        ('Y', 'N'): 0.81,
-        ('W', 'N'): 0.81,
-        ('C', 'N'): 0.8,
-        ('A', 'N'): 0.615,
-        ('G', 'N'): 0.525,
-        ('S', 'N'): 0.20500000000000002,
-        ('T', 'N'): 0.2,
-        ('H', 'N'): 0.21,
-        ('E', 'N'): 0.03,
-        ('Q', 'N'): 0.03,
-        ('D', 'N'): 0.0,
-        ('N', 'N'): 0.0,
-        ('K', 'N'): 0.03,
-        ('R', 'N'): 0.08,
-        ('F', 'K'): 1.0,
-        ('M', 'K'): 1.0,
-        ('L', 'K'): 1.0,
-        ('I', 'K'): 1.0,
-        ('V', 'K'): 1.0,
-        ('P', 'K'): 1.0,
-        ('Y', 'K'): 0.8,
-        ('W', 'K'): 0.81,
-        ('C', 'K'): 0.805,
-        ('A', 'K'): 0.62,
-        ('G', 'K'): 0.54,
-        ('S', 'K'): 0.215,
-        ('T', 'K'): 0.21,
-        ('H', 'K'): 0.2,
-        ('E', 'K'): 0.0,
-        ('Q', 'K'): 0.0,
-        ('D', 'K'): 0.03,
-        ('N', 'K'): 0.03,
-        ('K', 'K'): 0.0,
-        ('R', 'K'): 0.05,
-        ('F', 'R'): 1.0,
-        ('M', 'R'): 1.0,
-        ('L', 'R'): 1.005,
-        ('I', 'R'): 1.005,
-        ('V', 'R'): 1.0150000000000001,
-        ('P', 'R'): 1.0150000000000001,
-        ('Y', 'R'): 0.8,
-        ('W', 'R'): 0.8,
-        ('C', 'R'): 0.815,
-        ('A', 'R'): 0.645,
-        ('G', 'R'): 0.5700000000000001,
-        ('S', 'R'): 0.24,
-        ('T', 'R'): 0.22,
-        ('H', 'R'): 0.2,
-        ('E', 'R'): 0.05,
-        ('Q', 'R'): 0.05,
-        ('D', 'R'): 0.08,
-        ('N', 'R'): 0.08,
-        ('K', 'R'): 0.05,
-        ('R', 'R'): 0.0,
+        ("F", "M"): 0.075,
+        ("M", "F"): 0.075,
+        ("F", "L"): 0.115,
+        ("L", "F"): 0.115,
+        ("F", "I"): 0.115,
+        ("I", "F"): 0.115,
+        ("F", "V"): 0.15,
+        ("V", "F"): 0.15,
+        ("F", "P"): 0.15,
+        ("P", "F"): 0.15,
+        ("F", "Y"): 0.205,
+        ("Y", "F"): 0.205,
+        ("F", "W"): 0.23,
+        ("W", "F"): 0.23,
+        ("F", "C"): 0.25,
+        ("C", "F"): 0.25,
+        ("F", "A"): 0.465,
+        ("A", "F"): 0.465,
+        ("F", "G"): 0.57,
+        ("G", "F"): 0.57,
+        ("F", "S"): 0.81,
+        ("S", "F"): 0.81,
+        ("F", "T"): 0.81,
+        ("T", "F"): 0.81,
+        ("F", "H"): 0.8,
+        ("H", "F"): 0.8,
+        ("F", "E"): 1.0,
+        ("E", "F"): 1.0,
+        ("F", "Q"): 1.0,
+        ("Q", "F"): 1.0,
+        ("F", "D"): 1.0,
+        ("D", "F"): 1.0,
+        ("F", "N"): 1.0,
+        ("N", "F"): 1.0,
+        ("F", "K"): 1.0,
+        ("K", "F"): 1.0,
+        ("F", "R"): 1.0,
+        ("R", "F"): 1.0,
+        ("M", "L"): 0.04,
+        ("L", "M"): 0.04,
+        ("M", "I"): 0.04,
+        ("I", "M"): 0.04,
+        ("M", "V"): 0.1,
+        ("V", "M"): 0.1,
+        ("M", "P"): 0.1,
+        ("P", "M"): 0.1,
+        ("M", "Y"): 0.235,
+        ("Y", "M"): 0.235,
+        ("M", "W"): 0.28,
+        ("W", "M"): 0.28,
+        ("M", "C"): 0.215,
+        ("C", "M"): 0.215,
+        ("M", "A"): 0.43,
+        ("A", "M"): 0.43,
+        ("M", "G"): 0.49,
+        ("G", "M"): 0.49,
+        ("M", "S"): 0.8,
+        ("S", "M"): 0.8,
+        ("M", "T"): 0.8,
+        ("T", "M"): 0.8,
+        ("M", "H"): 0.8,
+        ("H", "M"): 0.8,
+        ("M", "E"): 1.0,
+        ("E", "M"): 1.0,
+        ("M", "Q"): 1.0,
+        ("Q", "M"): 1.0,
+        ("M", "D"): 1.0,
+        ("D", "M"): 1.0,
+        ("M", "N"): 1.0,
+        ("N", "M"): 1.0,
+        ("M", "K"): 1.0,
+        ("K", "M"): 1.0,
+        ("M", "R"): 1.0,
+        ("R", "M"): 1.0,
+        ("L", "I"): 0.0,
+        ("I", "L"): 0.0,
+        ("L", "V"): 0.04,
+        ("V", "L"): 0.04,
+        ("L", "P"): 0.04,
+        ("P", "L"): 0.04,
+        ("L", "Y"): 0.25,
+        ("Y", "L"): 0.25,
+        ("L", "W"): 0.305,
+        ("W", "L"): 0.305,
+        ("L", "C"): 0.205,
+        ("C", "L"): 0.205,
+        ("L", "A"): 0.43,
+        ("A", "L"): 0.43,
+        ("L", "G"): 0.525,
+        ("G", "L"): 0.525,
+        ("L", "S"): 0.8,
+        ("S", "L"): 0.8,
+        ("L", "T"): 0.8,
+        ("T", "L"): 0.8,
+        ("L", "H"): 0.905,
+        ("H", "L"): 0.905,
+        ("L", "E"): 1.0,
+        ("E", "L"): 1.0,
+        ("L", "Q"): 1.0,
+        ("Q", "L"): 1.0,
+        ("L", "D"): 1.0,
+        ("D", "L"): 1.0,
+        ("L", "N"): 1.0,
+        ("N", "L"): 1.0,
+        ("L", "K"): 1.0,
+        ("K", "L"): 1.0,
+        ("L", "R"): 1.005,
+        ("R", "L"): 1.005,
+        ("I", "V"): 0.04,
+        ("V", "I"): 0.04,
+        ("I", "P"): 0.04,
+        ("P", "I"): 0.04,
+        ("I", "Y"): 0.25,
+        ("Y", "I"): 0.25,
+        ("I", "W"): 0.305,
+        ("W", "I"): 0.305,
+        ("I", "C"): 0.205,
+        ("C", "I"): 0.205,
+        ("I", "A"): 0.43,
+        ("A", "I"): 0.43,
+        ("I", "G"): 0.525,
+        ("G", "I"): 0.525,
+        ("I", "S"): 0.8,
+        ("S", "I"): 0.8,
+        ("I", "T"): 0.8,
+        ("T", "I"): 0.8,
+        ("I", "H"): 0.905,
+        ("H", "I"): 0.905,
+        ("I", "E"): 1.0,
+        ("E", "I"): 1.0,
+        ("I", "Q"): 1.0,
+        ("Q", "I"): 1.0,
+        ("I", "D"): 1.0,
+        ("D", "I"): 1.0,
+        ("I", "N"): 1.0,
+        ("N", "I"): 1.0,
+        ("I", "K"): 1.0,
+        ("K", "I"): 1.0,
+        ("I", "R"): 1.005,
+        ("R", "I"): 1.005,
+        ("V", "P"): 0.0,
+        ("P", "V"): 0.0,
+        ("V", "Y"): 0.28,
+        ("Y", "V"): 0.28,
+        ("V", "W"): 0.335,
+        ("W", "V"): 0.335,
+        ("V", "C"): 0.2,
+        ("C", "V"): 0.2,
+        ("V", "A"): 0.405,
+        ("A", "V"): 0.405,
+        ("V", "G"): 0.51,
+        ("G", "V"): 0.51,
+        ("V", "S"): 0.8,
+        ("S", "V"): 0.8,
+        ("V", "T"): 0.8,
+        ("T", "V"): 0.8,
+        ("V", "H"): 0.805,
+        ("H", "V"): 0.805,
+        ("V", "E"): 1.0,
+        ("E", "V"): 1.0,
+        ("V", "Q"): 1.0,
+        ("Q", "V"): 1.0,
+        ("V", "D"): 1.0,
+        ("D", "V"): 1.0,
+        ("V", "N"): 1.0,
+        ("N", "V"): 1.0,
+        ("V", "K"): 1.0,
+        ("K", "V"): 1.0,
+        ("V", "R"): 1.015,
+        ("R", "V"): 1.015,
+        ("P", "Y"): 0.28,
+        ("Y", "P"): 0.28,
+        ("P", "W"): 0.335,
+        ("W", "P"): 0.335,
+        ("P", "C"): 0.2,
+        ("C", "P"): 0.2,
+        ("P", "A"): 0.405,
+        ("A", "P"): 0.405,
+        ("P", "G"): 0.51,
+        ("G", "P"): 0.51,
+        ("P", "S"): 0.8,
+        ("S", "P"): 0.8,
+        ("P", "T"): 0.8,
+        ("T", "P"): 0.8,
+        ("P", "H"): 0.805,
+        ("H", "P"): 0.805,
+        ("P", "E"): 1.0,
+        ("E", "P"): 1.0,
+        ("P", "Q"): 1.0,
+        ("Q", "P"): 1.0,
+        ("P", "D"): 1.0,
+        ("D", "P"): 1.0,
+        ("P", "N"): 1.0,
+        ("N", "P"): 1.0,
+        ("P", "K"): 1.0,
+        ("K", "P"): 1.0,
+        ("P", "R"): 1.015,
+        ("R", "P"): 1.015,
+        ("Y", "W"): 0.075,
+        ("W", "Y"): 0.075,
+        ("Y", "C"): 0.19,
+        ("C", "Y"): 0.19,
+        ("Y", "A"): 0.335,
+        ("A", "Y"): 0.335,
+        ("Y", "G"): 0.43,
+        ("G", "Y"): 0.43,
+        ("Y", "S"): 0.62,
+        ("S", "Y"): 0.62,
+        ("Y", "T"): 0.61,
+        ("T", "Y"): 0.61,
+        ("Y", "H"): 0.6,
+        ("H", "Y"): 0.6,
+        ("Y", "E"): 0.8,
+        ("E", "Y"): 0.8,
+        ("Y", "Q"): 0.8,
+        ("Q", "Y"): 0.8,
+        ("Y", "D"): 0.81,
+        ("D", "Y"): 0.81,
+        ("Y", "N"): 0.81,
+        ("N", "Y"): 0.81,
+        ("Y", "K"): 0.8,
+        ("K", "Y"): 0.8,
+        ("Y", "R"): 0.8,
+        ("R", "Y"): 0.8,
+        ("W", "C"): 0.265,
+        ("C", "W"): 0.265,
+        ("W", "A"): 0.395,
+        ("A", "W"): 0.395,
+        ("W", "G"): 0.485,
+        ("G", "W"): 0.485,
+        ("W", "S"): 0.63,
+        ("S", "W"): 0.63,
+        ("W", "T"): 0.63,
+        ("T", "W"): 0.63,
+        ("W", "H"): 0.61,
+        ("H", "W"): 0.61,
+        ("W", "E"): 0.81,
+        ("E", "W"): 0.81,
+        ("W", "Q"): 0.81,
+        ("Q", "W"): 0.81,
+        ("W", "D"): 0.81,
+        ("D", "W"): 0.81,
+        ("W", "N"): 0.81,
+        ("N", "W"): 0.81,
+        ("W", "K"): 0.81,
+        ("K", "W"): 0.81,
+        ("W", "R"): 0.8,
+        ("R", "W"): 0.8,
+        ("C", "A"): 0.235,
+        ("A", "C"): 0.235,
+        ("C", "G"): 0.325,
+        ("G", "C"): 0.325,
+        ("C", "S"): 0.6,
+        ("S", "C"): 0.6,
+        ("C", "T"): 0.6,
+        ("T", "C"): 0.6,
+        ("C", "H"): 0.615,
+        ("H", "C"): 0.615,
+        ("C", "E"): 0.805,
+        ("E", "C"): 0.805,
+        ("C", "Q"): 0.805,
+        ("Q", "C"): 0.805,
+        ("C", "D"): 0.8,
+        ("D", "C"): 0.8,
+        ("C", "N"): 0.8,
+        ("N", "C"): 0.8,
+        ("C", "K"): 0.805,
+        ("K", "C"): 0.805,
+        ("C", "R"): 0.815,
+        ("R", "C"): 0.815,
+        ("A", "G"): 0.1,
+        ("G", "A"): 0.1,
+        ("A", "S"): 0.4,
+        ("S", "A"): 0.4,
+        ("A", "T"): 0.405,
+        ("T", "A"): 0.405,
+        ("A", "H"): 0.445,
+        ("H", "A"): 0.445,
+        ("A", "E"): 0.62,
+        ("E", "A"): 0.62,
+        ("A", "Q"): 0.62,
+        ("Q", "A"): 0.62,
+        ("A", "D"): 0.615,
+        ("D", "A"): 0.615,
+        ("A", "N"): 0.615,
+        ("N", "A"): 0.615,
+        ("A", "K"): 0.62,
+        ("K", "A"): 0.62,
+        ("A", "R"): 0.645,
+        ("R", "A"): 0.645,
+        ("G", "S"): 0.31,
+        ("S", "G"): 0.31,
+        ("G", "T"): 0.325,
+        ("T", "G"): 0.325,
+        ("G", "H"): 0.38,
+        ("H", "G"): 0.38,
+        ("G", "E"): 0.54,
+        ("E", "G"): 0.54,
+        ("G", "Q"): 0.54,
+        ("Q", "G"): 0.54,
+        ("G", "D"): 0.525,
+        ("D", "G"): 0.525,
+        ("G", "N"): 0.525,
+        ("N", "G"): 0.525,
+        ("G", "K"): 0.54,
+        ("K", "G"): 0.54,
+        ("G", "R"): 0.57,
+        ("R", "G"): 0.57,
+        ("S", "T"): 0.03,
+        ("T", "S"): 0.03,
+        ("S", "H"): 0.1,
+        ("H", "S"): 0.1,
+        ("S", "E"): 0.215,
+        ("E", "S"): 0.215,
+        ("S", "Q"): 0.215,
+        ("Q", "S"): 0.215,
+        ("S", "D"): 0.205,
+        ("D", "S"): 0.205,
+        ("S", "N"): 0.205,
+        ("N", "S"): 0.205,
+        ("S", "K"): 0.215,
+        ("K", "S"): 0.215,
+        ("S", "R"): 0.24,
+        ("R", "S"): 0.24,
+        ("T", "H"): 0.08,
+        ("H", "T"): 0.08,
+        ("T", "E"): 0.21,
+        ("E", "T"): 0.21,
+        ("T", "Q"): 0.21,
+        ("Q", "T"): 0.21,
+        ("T", "D"): 0.2,
+        ("D", "T"): 0.2,
+        ("T", "N"): 0.2,
+        ("N", "T"): 0.2,
+        ("T", "K"): 0.21,
+        ("K", "T"): 0.21,
+        ("T", "R"): 0.22,
+        ("R", "T"): 0.22,
+        ("H", "E"): 0.2,
+        ("E", "H"): 0.2,
+        ("H", "Q"): 0.2,
+        ("Q", "H"): 0.2,
+        ("H", "D"): 0.21,
+        ("D", "H"): 0.21,
+        ("H", "N"): 0.21,
+        ("N", "H"): 0.21,
+        ("H", "K"): 0.2,
+        ("K", "H"): 0.2,
+        ("H", "R"): 0.2,
+        ("R", "H"): 0.2,
+        ("E", "Q"): 0.0,
+        ("Q", "E"): 0.0,
+        ("E", "D"): 0.03,
+        ("D", "E"): 0.03,
+        ("E", "N"): 0.03,
+        ("N", "E"): 0.03,
+        ("E", "K"): 0.0,
+        ("K", "E"): 0.0,
+        ("E", "R"): 0.05,
+        ("R", "E"): 0.05,
+        ("Q", "D"): 0.03,
+        ("D", "Q"): 0.03,
+        ("Q", "N"): 0.03,
+        ("N", "Q"): 0.03,
+        ("Q", "K"): 0.0,
+        ("K", "Q"): 0.0,
+        ("Q", "R"): 0.05,
+        ("R", "Q"): 0.05,
+        ("D", "N"): 0.0,
+        ("N", "D"): 0.0,
+        ("D", "K"): 0.03,
+        ("K", "D"): 0.03,
+        ("D", "R"): 0.08,
+        ("R", "D"): 0.08,
+        ("N", "K"): 0.03,
+        ("K", "N"): 0.03,
+        ("N", "R"): 0.08,
+        ("R", "N"): 0.08,
+        ("K", "R"): 0.05,
+        ("R", "K"): 0.05,
+        ("F", "F"): 0,
+        ("M", "M"): 0,
+        ("L", "L"): 0,
+        ("I", "I"): 0,
+        ("V", "V"): 0,
+        ("P", "P"): 0,
+        ("Y", "Y"): 0,
+        ("W", "W"): 0,
+        ("C", "C"): 0,
+        ("A", "A"): 0,
+        ("G", "G"): 0,
+        ("S", "S"): 0,
+        ("T", "T"): 0,
+        ("H", "H"): 0,
+        ("E", "E"): 0,
+        ("Q", "Q"): 0,
+        ("D", "D"): 0,
+        ("N", "N"): 0,
+        ("K", "K"): 0,
+        ("R", "R"): 0,
+    }
+
+
+    return epstein_dict
+
+
+def make_asymmetric_epstein_dict() -> dict[tuple[str, str], float]:
+    """
+    :return: A dictionary representative of TABLE 2 from 'Non-randomness of Amino-acid Changes in the Evolution of
+             Homologous Proteins' by Charles J. Epstein. Keys are pairs of strings. Cf. scientific paper for
+             more details on how those scores are derived.
+    """
+    epstein_dict: dict[tuple[str, str], float] = {
+        ("F", "M"): 0.05,
+        ("M", "F"): 0.1,
+        ("F", "L"): 0.08,
+        ("L", "F"): 0.15,
+        ("F", "I"): 0.08,
+        ("I", "F"): 0.15,
+        ("F", "V"): 0.1,
+        ("V", "F"): 0.2,
+        ("F", "P"): 0.1,
+        ("P", "F"): 0.2,
+        ("F", "Y"): 0.21,
+        ("Y", "F"): 0.2,
+        ("F", "W"): 0.25,
+        ("W", "F"): 0.21,
+        ("F", "C"): 0.22,
+        ("C", "F"): 0.28,
+        ("F", "A"): 0.43,
+        ("A", "F"): 0.5,
+        ("F", "G"): 0.53,
+        ("G", "F"): 0.61,
+        ("F", "S"): 0.81,
+        ("S", "F"): 0.81,
+        ("F", "T"): 0.81,
+        ("T", "F"): 0.81,
+        ("F", "H"): 0.8,
+        ("H", "F"): 0.8,
+        ("F", "E"): 1.0,
+        ("E", "F"): 1.0,
+        ("F", "Q"): 1.0,
+        ("Q", "F"): 1.0,
+        ("F", "D"): 1.0,
+        ("D", "F"): 1.0,
+        ("F", "N"): 1.0,
+        ("N", "F"): 1.0,
+        ("F", "K"): 1.0,
+        ("K", "F"): 1.0,
+        ("F", "R"): 1.0,
+        ("R", "F"): 1.0,
+        ("M", "L"): 0.03,
+        ("L", "M"): 0.05,
+        ("M", "I"): 0.03,
+        ("I", "M"): 0.05,
+        ("M", "V"): 0.1,
+        ("V", "M"): 0.1,
+        ("M", "P"): 0.1,
+        ("P", "M"): 0.1,
+        ("M", "Y"): 0.25,
+        ("Y", "M"): 0.22,
+        ("M", "W"): 0.32,
+        ("W", "M"): 0.24,
+        ("M", "C"): 0.21,
+        ("C", "M"): 0.22,
+        ("M", "A"): 0.41,
+        ("A", "M"): 0.45,
+        ("M", "G"): 0.42,
+        ("G", "M"): 0.56,
+        ("M", "S"): 0.8,
+        ("S", "M"): 0.8,
+        ("M", "T"): 0.8,
+        ("T", "M"): 0.8,
+        ("M", "H"): 0.8,
+        ("H", "M"): 0.8,
+        ("M", "E"): 1.0,
+        ("E", "M"): 1.0,
+        ("M", "Q"): 1.0,
+        ("Q", "M"): 1.0,
+        ("M", "D"): 1.0,
+        ("D", "M"): 1.0,
+        ("M", "N"): 1.0,
+        ("N", "M"): 1.0,
+        ("M", "K"): 1.0,
+        ("K", "M"): 1.0,
+        ("M", "R"): 1.0,
+        ("R", "M"): 1.0,
+        ("L", "I"): 0.0,
+        ("I", "L"): 0.0,
+        ("L", "V"): 0.03,
+        ("V", "L"): 0.05,
+        ("L", "P"): 0.03,
+        ("P", "L"): 0.05,
+        ("L", "Y"): 0.28,
+        ("Y", "L"): 0.22,
+        ("L", "W"): 0.36,
+        ("W", "L"): 0.25,
+        ("L", "C"): 0.2,
+        ("C", "L"): 0.21,
+        ("L", "A"): 0.43,
+        ("A", "L"): 0.43,
+        ("L", "G"): 0.51,
+        ("G", "L"): 0.54,
+        ("L", "S"): 0.8,
+        ("S", "L"): 0.8,
+        ("L", "T"): 0.8,
+        ("T", "L"): 0.8,
+        ("L", "H"): 0.81,
+        ("H", "L"): 1.0,
+        ("L", "E"): 1.0,
+        ("E", "L"): 1.0,
+        ("L", "Q"): 1.0,
+        ("Q", "L"): 1.0,
+        ("L", "D"): 1.0,
+        ("D", "L"): 1.0,
+        ("L", "N"): 1.0,
+        ("N", "L"): 1.0,
+        ("L", "K"): 1.0,
+        ("K", "L"): 1.0,
+        ("L", "R"): 1.01,
+        ("R", "L"): 1.0,
+        ("I", "V"): 0.03,
+        ("V", "I"): 0.05,
+        ("I", "P"): 0.03,
+        ("P", "I"): 0.05,
+        ("I", "Y"): 0.28,
+        ("Y", "I"): 0.22,
+        ("I", "W"): 0.36,
+        ("W", "I"): 0.25,
+        ("I", "C"): 0.2,
+        ("C", "I"): 0.21,
+        ("I", "A"): 0.43,
+        ("A", "I"): 0.43,
+        ("I", "G"): 0.51,
+        ("G", "I"): 0.54,
+        ("I", "S"): 0.8,
+        ("S", "I"): 0.8,
+        ("I", "T"): 0.8,
+        ("T", "I"): 0.8,
+        ("I", "H"): 0.81,
+        ("H", "I"): 1.0,
+        ("I", "E"): 1.0,
+        ("E", "I"): 1.0,
+        ("I", "Q"): 1.0,
+        ("Q", "I"): 1.0,
+        ("I", "D"): 1.0,
+        ("D", "I"): 1.0,
+        ("I", "N"): 1.0,
+        ("N", "I"): 1.0,
+        ("I", "K"): 1.0,
+        ("K", "I"): 1.0,
+        ("I", "R"): 1.01,
+        ("R", "I"): 1.0,
+        ("V", "P"): 0.0,
+        ("P", "V"): 0.0,
+        ("V", "Y"): 0.32,
+        ("Y", "V"): 0.24,
+        ("V", "W"): 0.4,
+        ("W", "V"): 0.27,
+        ("V", "C"): 0.2,
+        ("C", "V"): 0.2,
+        ("V", "A"): 0.4,
+        ("A", "V"): 0.41,
+        ("V", "G"): 0.5,
+        ("G", "V"): 0.52,
+        ("V", "S"): 0.8,
+        ("S", "V"): 0.8,
+        ("V", "T"): 0.8,
+        ("T", "V"): 0.8,
+        ("V", "H"): 0.81,
+        ("H", "V"): 0.8,
+        ("V", "E"): 1.0,
+        ("E", "V"): 1.0,
+        ("V", "Q"): 1.0,
+        ("Q", "V"): 1.0,
+        ("V", "D"): 1.0,
+        ("D", "V"): 1.0,
+        ("V", "N"): 1.0,
+        ("N", "V"): 1.0,
+        ("V", "K"): 1.0,
+        ("K", "V"): 1.0,
+        ("V", "R"): 1.02,
+        ("R", "V"): 1.01,
+        ("P", "Y"): 0.32,
+        ("Y", "P"): 0.24,
+        ("P", "W"): 0.4,
+        ("W", "P"): 0.27,
+        ("P", "C"): 0.2,
+        ("C", "P"): 0.2,
+        ("P", "A"): 0.4,
+        ("A", "P"): 0.41,
+        ("P", "G"): 0.5,
+        ("G", "P"): 0.52,
+        ("P", "S"): 0.8,
+        ("S", "P"): 0.8,
+        ("P", "T"): 0.8,
+        ("T", "P"): 0.8,
+        ("P", "H"): 0.81,
+        ("H", "P"): 0.8,
+        ("P", "E"): 1.0,
+        ("E", "P"): 1.0,
+        ("P", "Q"): 1.0,
+        ("Q", "P"): 1.0,
+        ("P", "D"): 1.0,
+        ("D", "P"): 1.0,
+        ("P", "N"): 1.0,
+        ("N", "P"): 1.0,
+        ("P", "K"): 1.0,
+        ("K", "P"): 1.0,
+        ("P", "R"): 1.02,
+        ("R", "P"): 1.01,
+        ("Y", "W"): 0.1,
+        ("W", "Y"): 0.05,
+        ("Y", "C"): 0.13,
+        ("C", "Y"): 0.25,
+        ("Y", "A"): 0.27,
+        ("A", "Y"): 0.4,
+        ("Y", "G"): 0.36,
+        ("G", "Y"): 0.5,
+        ("Y", "S"): 0.62,
+        ("S", "Y"): 0.62,
+        ("Y", "T"): 0.61,
+        ("T", "Y"): 0.61,
+        ("Y", "H"): 0.6,
+        ("H", "Y"): 0.6,
+        ("Y", "E"): 0.8,
+        ("E", "Y"): 0.8,
+        ("Y", "Q"): 0.8,
+        ("Q", "Y"): 0.8,
+        ("Y", "D"): 0.81,
+        ("D", "Y"): 0.81,
+        ("Y", "N"): 0.81,
+        ("N", "Y"): 0.81,
+        ("Y", "K"): 0.8,
+        ("K", "Y"): 0.8,
+        ("Y", "R"): 0.8,
+        ("R", "Y"): 0.8,
+        ("W", "C"): 0.18,
+        ("C", "W"): 0.35,
+        ("W", "A"): 0.3,
+        ("A", "W"): 0.49,
+        ("W", "G"): 0.39,
+        ("G", "W"): 0.58,
+        ("W", "S"): 0.63,
+        ("S", "W"): 0.63,
+        ("W", "T"): 0.63,
+        ("T", "W"): 0.63,
+        ("W", "H"): 0.61,
+        ("H", "W"): 0.61,
+        ("W", "E"): 0.81,
+        ("E", "W"): 0.81,
+        ("W", "Q"): 0.81,
+        ("Q", "W"): 0.81,
+        ("W", "D"): 0.81,
+        ("D", "W"): 0.81,
+        ("W", "N"): 0.81,
+        ("N", "W"): 0.81,
+        ("W", "K"): 0.81,
+        ("K", "W"): 0.81,
+        ("W", "R"): 0.8,
+        ("R", "W"): 0.8,
+        ("C", "A"): 0.25,
+        ("A", "C"): 0.22,
+        ("C", "G"): 0.31,
+        ("G", "C"): 0.34,
+        ("C", "S"): 0.6,
+        ("S", "C"): 0.6,
+        ("C", "T"): 0.6,
+        ("T", "C"): 0.6,
+        ("C", "H"): 0.62,
+        ("H", "C"): 0.61,
+        ("C", "E"): 0.81,
+        ("E", "C"): 0.8,
+        ("C", "Q"): 0.81,
+        ("Q", "C"): 0.8,
+        ("C", "D"): 0.8,
+        ("D", "C"): 0.8,
+        ("C", "N"): 0.8,
+        ("N", "C"): 0.8,
+        ("C", "K"): 0.81,
+        ("K", "C"): 0.8,
+        ("C", "R"): 0.82,
+        ("R", "C"): 0.81,
+        ("A", "G"): 0.1,
+        ("G", "A"): 0.1,
+        ("A", "S"): 0.4,
+        ("S", "A"): 0.4,
+        ("A", "T"): 0.41,
+        ("T", "A"): 0.4,
+        ("A", "H"): 0.47,
+        ("H", "A"): 0.42,
+        ("A", "E"): 0.63,
+        ("E", "A"): 0.61,
+        ("A", "Q"): 0.63,
+        ("Q", "A"): 0.61,
+        ("A", "D"): 0.62,
+        ("D", "A"): 0.61,
+        ("A", "N"): 0.62,
+        ("N", "A"): 0.61,
+        ("A", "K"): 0.63,
+        ("K", "A"): 0.61,
+        ("A", "R"): 0.67,
+        ("R", "A"): 0.62,
+        ("G", "S"): 0.32,
+        ("S", "G"): 0.3,
+        ("G", "T"): 0.34,
+        ("T", "G"): 0.31,
+        ("G", "H"): 0.42,
+        ("H", "G"): 0.34,
+        ("G", "E"): 0.56,
+        ("E", "G"): 0.52,
+        ("G", "Q"): 0.56,
+        ("Q", "G"): 0.52,
+        ("G", "D"): 0.54,
+        ("D", "G"): 0.51,
+        ("G", "N"): 0.54,
+        ("N", "G"): 0.51,
+        ("G", "K"): 0.56,
+        ("K", "G"): 0.52,
+        ("G", "R"): 0.61,
+        ("R", "G"): 0.53,
+        ("S", "T"): 0.03,
+        ("T", "S"): 0.03,
+        ("S", "H"): 0.1,
+        ("H", "S"): 0.1,
+        ("S", "E"): 0.21,
+        ("E", "S"): 0.22,
+        ("S", "Q"): 0.21,
+        ("Q", "S"): 0.22,
+        ("S", "D"): 0.2,
+        ("D", "S"): 0.21,
+        ("S", "N"): 0.2,
+        ("N", "S"): 0.21,
+        ("S", "K"): 0.21,
+        ("K", "S"): 0.22,
+        ("S", "R"): 0.24,
+        ("R", "S"): 0.24,
+        ("T", "H"): 0.08,
+        ("H", "T"): 0.08,
+        ("T", "E"): 0.21,
+        ("E", "T"): 0.21,
+        ("T", "Q"): 0.21,
+        ("Q", "T"): 0.21,
+        ("T", "D"): 0.2,
+        ("D", "T"): 0.2,
+        ("T", "N"): 0.2,
+        ("N", "T"): 0.2,
+        ("T", "K"): 0.21,
+        ("K", "T"): 0.21,
+        ("T", "R"): 0.22,
+        ("R", "T"): 0.22,
+        ("H", "E"): 0.2,
+        ("E", "H"): 0.2,
+        ("H", "Q"): 0.2,
+        ("Q", "H"): 0.2,
+        ("H", "D"): 0.21,
+        ("D", "H"): 0.21,
+        ("H", "N"): 0.21,
+        ("N", "H"): 0.21,
+        ("H", "K"): 0.2,
+        ("K", "H"): 0.2,
+        ("H", "R"): 0.2,
+        ("R", "H"): 0.2,
+        ("E", "Q"): 0.0,
+        ("Q", "E"): 0.0,
+        ("E", "D"): 0.03,
+        ("D", "E"): 0.03,
+        ("E", "N"): 0.03,
+        ("N", "E"): 0.03,
+        ("E", "K"): 0.0,
+        ("K", "E"): 0.0,
+        ("E", "R"): 0.05,
+        ("R", "E"): 0.05,
+        ("Q", "D"): 0.03,
+        ("D", "Q"): 0.03,
+        ("Q", "N"): 0.03,
+        ("N", "Q"): 0.03,
+        ("Q", "K"): 0.0,
+        ("K", "Q"): 0.0,
+        ("Q", "R"): 0.05,
+        ("R", "Q"): 0.05,
+        ("D", "N"): 0.0,
+        ("N", "D"): 0.0,
+        ("D", "K"): 0.03,
+        ("K", "D"): 0.03,
+        ("D", "R"): 0.08,
+        ("R", "D"): 0.08,
+        ("N", "K"): 0.03,
+        ("K", "N"): 0.03,
+        ("N", "R"): 0.08,
+        ("R", "N"): 0.08,
+        ("K", "R"): 0.05,
+        ("R", "K"): 0.05,
+        ("F", "F"): 0,
+        ("M", "M"): 0,
+        ("L", "L"): 0,
+        ("I", "I"): 0,
+        ("V", "V"): 0,
+        ("P", "P"): 0,
+        ("Y", "Y"): 0,
+        ("W", "W"): 0,
+        ("C", "C"): 0,
+        ("A", "A"): 0,
+        ("G", "G"): 0,
+        ("S", "S"): 0,
+        ("T", "T"): 0,
+        ("H", "H"): 0,
+        ("E", "E"): 0,
+        ("Q", "Q"): 0,
+        ("D", "D"): 0,
+        ("N", "N"): 0,
+        ("K", "K"): 0,
+        ("R", "R"): 0,
     }
 
     return epstein_dict
@@ -1226,9 +1650,9 @@ def make_epstein_dict() -> dict[tuple[str, str], float]:
 
 def make_symmetric_experimental_exchangeability_dict() -> dict[tuple[str, str], float]:
     """
-    :return: A dictionary representative of TABLE 2 & 3 from The Exchangeability of Amino Acids in Proteins by Lev Y.
+    :return: A dictionary representative of TABLE 2 & 3 from 'The Exchangeability of Amino Acids in Proteins' by Lev Y.
              Yampolsky and Arlin Stoltzfus. Keys are pairs of strings. Cf. scientific paper for more details on how
-             those scores are derived.
+             those scores are derived. Cf. paper for formula used to infer the symmetrised version (weighted mean).
              It does not have any missing values like the asymmetrical verison does, cf. article:
              'The symmetric matrix EXSij has no missing values because exchange data are available for every possible
               unordered pair of amino acids.'
@@ -1641,7 +2065,7 @@ def make_symmetric_experimental_exchangeability_dict() -> dict[tuple[str, str],
 
 def make_asymmetric_experimental_exchangeability_dict() -> dict[tuple[str, str], int | None]:
     """
-    :return: A dictionary representative of TABLE 3 from The Exchangeability of Amino Acids in Proteins by Lev Y.
+    :return: A dictionary representative of TABLE 3 from 'The Exchangeability of Amino Acids in Proteins' by Lev Y.
              Yampolsky and Arlin Stoltzfus. Keys are pairs of strings. First string of the tuple is the source and
              second string of the tuple is the destination. Cf. scientific paper for more details on how those
              scores are derived.
@@ -2054,6 +2478,11 @@ def make_asymmetric_experimental_exchangeability_dict() -> dict[tuple[str, str],
 
 
 def make_grantham_dict() -> dict[tuple[str, str], int]:
+    """
+    :return: A dictionary representative of TABLE 2 from 'Amino Acid Difference Formula to Help Explain Protein
+             Evolution' by R. Grantham. Keys are pairs of strings. Cf. scientific paper for more details on how
+             those scores are derived.
+    """
     grantham_dict = {
         ('A', 'A'): 0,
         ('A', 'C'): 195,
@@ -2460,5 +2889,19 @@ def make_grantham_dict() -> dict[tuple[str, str], int]:
     return grantham_dict
 
 
-GRANTHAM_DICT: dict[tuple[str, str], int] = make_grantham_dict()
-SNEATH_DICT: dict[tuple[str, str], int] = make_sneath_dict()
+SNEATH_DICT: dict[tuple[str, str], int]
+MIYATA_DICT: dict[tuple[str, str], float]
+SYMMETRIC_EPSTEIN_DICT: dict[tuple[str, str], float]
+ASYMMETRIC_EPSTEIN_DICT: dict[tuple[str, str], float]
+SYMMETRIC_EXPERIMENTAL_EXCHANGEABILITY_DICT: dict[tuple[str, str], float]
+ASYMMETRIC_EXPERIMENTAL_EXCHANGEABILITY_DICT: dict[tuple[str, str], int | None]
+GRANTHAM_DICT: dict[tuple[str, str], int]
+
+
+SNEATH_DICT                                  = make_sneath_dict()
+MIYATA_DICT                                  = make_miyata_dict()
+SYMMETRIC_EPSTEIN_DICT                       = make_symmetric_epstein_dict()
+ASYMMETRIC_EPSTEIN_DICT                      = make_asymmetric_epstein_dict()
+SYMMETRIC_EXPERIMENTAL_EXCHANGEABILITY_DICT  = make_symmetric_experimental_exchangeability_dict()
+ASYMMETRIC_EXPERIMENTAL_EXCHANGEABILITY_DICT = make_asymmetric_experimental_exchangeability_dict()
+GRANTHAM_DICT                                = make_grantham_dict()
